Pattern

Enum Pattern 

pub enum Pattern<T, X> {
    Ground(T),
    Var(X),
}
Resource or variable.

Used as a triple/quad component to represent either a fixed (Ground) resource, or a Variable that may be substituted for any resource.

Variants



Ground(T)

Ground (fixed) resource.



Var(X)

Variable, matching any resource.

Implementations

Source

impl<T, X> Pattern<T, X>

pub fn as_ref(&self) -> Pattern<&T, &X>

Borrows the ground value or variable of this pattern.

pub fn as_deref(&self) -> Pattern<&T::Target, &X::Target>
where T: Deref, X: Deref,

Dereferences the ground value or variable of this pattern.

pub fn is_ground(&self) -> bool

Checks if this pattern is a ground value (as opposed to a variable).

pub fn is_ground_and(&self, f: impl FnOnce(&T) -> bool) -> bool

Returns true if this pattern is a ground value satisfying the given predicate, and false if it is a variable.

pub fn is_var(&self) -> bool

Checks if this pattern is a variable (as opposed to a ground value).

pub fn is_var_and(&self, f: impl FnOnce(&X) -> bool) -> bool

Returns true if this pattern is a variable satisfying the given predicate, and false if it is a ground value.

pub fn is_ground_or(&self, f: impl FnOnce(&X) -> bool) -> bool

Returns true if this pattern is a ground value, or if it is a variable satisfying the given predicate.

Mirrors Option::is_none_or, with Self::Ground playing the role of None.

pub fn is_var_or(&self, f: impl FnOnce(&T) -> bool) -> bool

Returns true if this pattern is a variable, or if it is a ground value satisfying the given predicate.

Mirrors Option::is_none_or, with Self::Var playing the role of None.

pub fn map<U>(self, f: impl FnOnce(T) -> U) -> Pattern<U, X>

Maps the ground value with the given function, leaving a variable untouched.

pub fn map_var<Y>(self, f: impl FnOnce(X) -> Y) -> Pattern<T, Y>

Maps the variable with the given function, leaving a ground value untouched.