MultiPatternMatchingGraph

Trait MultiPatternMatchingGraph 

pub trait MultiPatternMatchingGraph: Graph {
    type TripleMultiPatternMatching<'a, 'p>: Iterator<Item = Triple<&'a Self::Resource>>
       where Self: 'a,
             Self::Resource: 'p;

    // Required method
    fn triple_multi_pattern_matching<'p, P: IntoIterator<Item = &'p Self::Resource>>(
        &self,
        pattern: LinearTriplePattern<P>,
    ) -> Self::TripleMultiPatternMatching<'_, 'p>;
}
Multi-pattern-matching-capable graph.

Unlike PatternMatchingGraph, each component of the pattern may match any resource from a given set, rather than at most one fixed resource.

Required Associated Types

type TripleMultiPatternMatching<'a, 'p>: Iterator<Item = Triple<&'a Self::Resource>> where Self: 'a, Self::Resource: 'p

Pattern-matching iterator.

Required Methods

fn triple_multi_pattern_matching<'p, P: IntoIterator<Item = &'p Self::Resource>>( &self, pattern: LinearTriplePattern<P>, ) -> Self::TripleMultiPatternMatching<'_, 'p>

Returns an iterator over all the triples of the graph matching the given pattern.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors