PatternMatchingGraphMut

Trait PatternMatchingGraphMut 

pub trait PatternMatchingGraphMut: PatternMatchingGraph {
    type ExtractMatchingTriples<'a, 'p>: Iterator<Item = Triple<Self::Resource>>
       where Self: 'a,
             Self::Resource: 'p;

    // Required method
    fn extract_matching_triples<'p>(
        &mut self,
        pattern: impl Into<LinearTriplePattern<&'p Self::Resource>>,
    ) -> Self::ExtractMatchingTriples<'_, 'p>
       where Self::Resource: 'p;
}
Pattern-matching-capable mutable graph.

Required Associated Types

type ExtractMatchingTriples<'a, 'p>: Iterator<Item = Triple<Self::Resource>> where Self: 'a, Self::Resource: 'p

Pattern-matching iterator.

Required Methods

fn extract_matching_triples<'p>( &mut self, pattern: impl Into<LinearTriplePattern<&'p Self::Resource>>, ) -> Self::ExtractMatchingTriples<'_, 'p>
where Self::Resource: 'p,

Returns an iterator over all the triples matching the given linear triple pattern.

Each matching triple returned by Iterator::next are removed from the graph. Matching triples that are not iterated on are kept in the graph, even when the iterator is dropped.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors